declare enum BifrostFormQuestionType {
    TEXT_INPUT = "TEXT_INPUT",
    EMAIL = "EMAIL",
    PHONE = "PHONE",
    TEXT_AREA = "TEXT_AREA",
    TOGGLE_BUTTON_GROUP = "TOGGLE_BUTTON_GROUP",
    SELECT_DATE_RANGE = "SELECT_DATE_RANGE",
    MULTI_SELECT_DATE_RANGE = "MULTI_SELECT_DATE_RANGE",
    SPLIT_TEXT_INPUT = "SPLIT_TEXT_INPUT"
}
interface BaseRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType;
    bifrostFormQuestionId: string;
    chatLabel: string;
}
interface SingleRenderableBifrostFormQuestion extends BaseRenderableBifrostFormQuestion {
    label: string;
    required?: boolean;
}
interface RenderableTextInputBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.TEXT_INPUT;
    autocomplete?: string;
}
interface RenderableEmailInputBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.EMAIL;
    autocomplete?: string;
}
interface RenderablePhoneInputBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.PHONE;
    autocomplete?: string;
}
interface RenderableTextAreaBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.TEXT_AREA;
}
interface RenderableToggleButtonGroupBifrostFormQuestionOption {
    label: string;
    value: string;
}
interface RenderableToggleButtonGroupBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.TOGGLE_BUTTON_GROUP;
    options: RenderableToggleButtonGroupBifrostFormQuestionOption[];
}
interface RenderableSelectDateRangeBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.SELECT_DATE_RANGE;
}
interface RenderableMultiSelectDateRangeBifrostFormQuestion extends SingleRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.MULTI_SELECT_DATE_RANGE;
}
interface RenderableSplitTextInputBifrostFormQuestion extends BaseRenderableBifrostFormQuestion {
    type: BifrostFormQuestionType.SPLIT_TEXT_INPUT;
    label?: string;
    left: RenderableTextInputBifrostFormQuestion;
    right: RenderableTextInputBifrostFormQuestion;
}
type BifrostFormQuestion = RenderableTextInputBifrostFormQuestion | RenderableEmailInputBifrostFormQuestion | RenderablePhoneInputBifrostFormQuestion | RenderableTextAreaBifrostFormQuestion | RenderableToggleButtonGroupBifrostFormQuestion | RenderableSelectDateRangeBifrostFormQuestion | RenderableMultiSelectDateRangeBifrostFormQuestion | RenderableSplitTextInputBifrostFormQuestion;

interface CalendarDate {
    /**
     * Year of the date
     * @type {number}
     * @memberof CalendarDate
     */
    year: number;
    /**
     * One-indexed month of the date (January is 1)
     * @type {number}
     * @memberof CalendarDate
     */
    month: number;
    /**
     * Day of the date
     * @type {number}
     * @memberof CalendarDate
     */
    day: number;
    /**
     * Timezone of the date. Provided by Intl.DateTimeFormat().resolvedOptions().timeZone. All options viewable by Intl.supportedValuesOf(\"timeZone\")
     * @type {string}
     * @memberof CalendarDate
     */
    timeZone?: string;
}

interface CalendarDateRange {
    startCalendarDate: CalendarDate;
    endCalendarDate: CalendarDate;
}
interface PendingCalendarDateRange {
    startCalendarDate?: CalendarDate;
    endCalendarDate?: CalendarDate;
}

declare enum BifrostFormQuestionResponseType {
    TEXT = "TEXT",
    PHONE_NUMBER = "PHONE_NUMBER",
    EMAIL = "EMAIL",
    CALENDAR_DATE_RANGE = "CALENDAR_DATE_RANGE",
    MULTI_CALENDAR_DATE_RANGE = "MULTI_CALENDAR_DATE_RANGE",
    SPLIT_TEXT = "SPLIT_TEXT"
}
interface BaseBifrostFormQuestionResponse {
    type: BifrostFormQuestionResponseType;
}
interface BifrostFormQuestionTextResponse {
    type: BifrostFormQuestionResponseType.TEXT;
    responseValue: string;
}
interface BifrostFormQuestionPhoneNumberResponse {
    type: BifrostFormQuestionResponseType.PHONE_NUMBER;
    responseValue: string;
}
interface BifrostFormQuestionEmailResponse {
    type: BifrostFormQuestionResponseType.EMAIL;
    responseValue: string;
}
interface BifrostFormQuestionCalendarDateRangeResponse {
    type: BifrostFormQuestionResponseType.CALENDAR_DATE_RANGE;
    responseValue: PendingCalendarDateRange;
}
interface BifrostFormQuestionMultiCalendarDateRangeResponse {
    type: BifrostFormQuestionResponseType.MULTI_CALENDAR_DATE_RANGE;
    responseValue: PendingCalendarDateRange[];
}
interface BifrostFormQuestionSplitTextResponse {
    type: BifrostFormQuestionResponseType.SPLIT_TEXT;
    responseValue: {
        left: string;
        right: string;
    };
}
type BifrostFormQuestionResponse = BifrostFormQuestionTextResponse | BifrostFormQuestionPhoneNumberResponse | BifrostFormQuestionEmailResponse | BifrostFormQuestionCalendarDateRangeResponse | BifrostFormQuestionMultiCalendarDateRangeResponse | BifrostFormQuestionSplitTextResponse;

interface BaseBifrostFormQuestionWithResponse {
    responseType: BifrostFormQuestionResponseType;
    bifrostFormQuestion: BifrostFormQuestion;
    responseData: BifrostFormQuestionResponse;
}
interface BifrostTextInputFormQuestionWithTextResponse {
    responseType: BifrostFormQuestionResponseType.TEXT;
    bifrostFormQuestion: RenderableTextInputBifrostFormQuestion;
    responseData: BifrostFormQuestionTextResponse;
}
interface BifrostTextAreaFormQuestionWithTextResponse {
    responseType: BifrostFormQuestionResponseType.TEXT;
    bifrostFormQuestion: RenderableTextAreaBifrostFormQuestion;
    responseData: BifrostFormQuestionTextResponse;
}
interface BifrostToggleButtonGroupFormQuestionWithTextResponse {
    responseType: BifrostFormQuestionResponseType.TEXT;
    bifrostFormQuestion: RenderableToggleButtonGroupBifrostFormQuestion;
    responseData: BifrostFormQuestionTextResponse;
}
type BifrostFormQuestionWithTextResponse = BifrostTextInputFormQuestionWithTextResponse | BifrostTextAreaFormQuestionWithTextResponse | BifrostToggleButtonGroupFormQuestionWithTextResponse;
interface BifrostFormQuestionWithPhoneNumberResponse {
    responseType: BifrostFormQuestionResponseType.PHONE_NUMBER;
    bifrostFormQuestion: RenderablePhoneInputBifrostFormQuestion;
    responseData: BifrostFormQuestionPhoneNumberResponse;
}
interface BifrostFormQuestionWithEmailResponse {
    responseType: BifrostFormQuestionResponseType.EMAIL;
    bifrostFormQuestion: RenderableEmailInputBifrostFormQuestion;
    responseData: BifrostFormQuestionEmailResponse;
}
interface BifrostFormQuestionWithCalendarDateRangeResponse {
    responseType: BifrostFormQuestionResponseType.CALENDAR_DATE_RANGE;
    bifrostFormQuestion: RenderableSelectDateRangeBifrostFormQuestion;
    responseData: BifrostFormQuestionCalendarDateRangeResponse;
}
interface BifrostFormQuestionWithMultiCalendarDateRangeResponse {
    responseType: BifrostFormQuestionResponseType.MULTI_CALENDAR_DATE_RANGE;
    bifrostFormQuestion: RenderableMultiSelectDateRangeBifrostFormQuestion;
    responseData: BifrostFormQuestionMultiCalendarDateRangeResponse;
}
interface BifrostFormQuestionWithSplitTextResponse {
    responseType: BifrostFormQuestionResponseType.SPLIT_TEXT;
    bifrostFormQuestion: RenderableSplitTextInputBifrostFormQuestion;
    responseData: BifrostFormQuestionSplitTextResponse;
}
type BifrostFormQuestionWithResponse = BifrostFormQuestionWithTextResponse | BifrostFormQuestionWithPhoneNumberResponse | BifrostFormQuestionWithEmailResponse | BifrostFormQuestionWithCalendarDateRangeResponse | BifrostFormQuestionWithMultiCalendarDateRangeResponse | BifrostFormQuestionWithSplitTextResponse;

declare enum ReservedBifrostFormQuestionIds {
    FIRST_NAME = "First Name",
    LAST_NAME = "Last Name",
    EMAIL = "Email",
    PHONE = "Phone",
    INQUIRY_DETAILS = "Inquiry Details",
    REASON_FOR_TRAVEL = "Reason for Travel",
    ARE_ITINERARY_DATES_FLEXIBLE = "Are Itinerary Dates Flexible",
    DATES = "Dates",
    POTENTIAL_DATES = "Potential Dates",
    FLEXIBLE_DATE_DESCRIPTION = "Flexible Date Description",
    ESTIMATED_GUEST_COUNT = "Estimated Guest Count",
    COUNT_OF_ROOMS_NEEDED = "Count of Rooms Needed",
    PAYMENT_SPLIT = "Payment Split"
}

declare enum ReservedBifrostReasonForTravelOptionValues {
    BUSINESS = "BUSINESS",
    SOCIAL = "SOCIAL",
    OTHER = "OTHER",
    EXTENDED_STAY = "EXTENDED_STAY"
}
declare enum ReservedBifrostSplitPaymentOptionValues {
    SINGLE_PAYER = "SINGLE_PAYER",
    SPLIT_PAYER = "SPLIT_PAYER"
}
declare enum ReservedBifrostDateFlexibilityOptionValues {
    FIRM_DATES = "FIRM_DATES",
    FLEXIBLE_DATES = "FLEXIBLE_DATES",
    STILL_DECIDING = "STILL_DECIDING"
}

declare enum ItineraryOfferOriginatorType {
    KISMET_AI = "KISMET_AI",
    GUEST = "GUEST",
    SALES_AGENT = "SALES_AGENT"
}
interface RenderableItineraryOfferBookingRules {
    holdDurationInDays: number;
    discountExpiresAtTimestamp: number;
    depositPercentage: number;
    depositCollectionTimestamp: number;
    paymentCollectionTimestamp: number;
}
interface RenderableItineraryOfferCriterion {
    criterionName: string;
    doesMatchCriterion: boolean;
}
interface RenderableItineraryHotelRoomOffer {
    hotelRoomId: string;
    countOffered: number;
    countAvailable: number;
    offerPriceInCents: number;
    listPriceInCents: number;
    hotelRoomName: string;
    hotelRoomDescription: string;
    verboseHotelRoomDescription: string;
    heroImageUrl: string;
    hotelRoomImageUrls: string[];
}
declare enum RenderableItineraryEventOfferApprovalStatus {
    PENDING = "Pending"
}
interface RenderableItineraryEventOffer {
    eventOfferId: string;
    eventName: string;
    calendarDateRange: CalendarDateRange;
    approvalStatus: RenderableItineraryEventOfferApprovalStatus;
    imageUrl: string;
}
interface RenderableItineraryOffer {
    itineraryOfferId: string;
    originatorType: ItineraryOfferOriginatorType;
    heroImageUrl: string;
    guestCount?: number;
    startCalendarDate: CalendarDate;
    endCalendarDate: CalendarDate;
    itineraryOfferName: string;
    itineraryOfferDescription: string;
    descriptionOfAllHotelRoomOffers: string;
    hotelRoomOffers: RenderableItineraryHotelRoomOffer[];
    descriptionOfAllEventOffers: string;
    eventOffers: RenderableItineraryEventOffer[];
    criteria: RenderableItineraryOfferCriterion[];
    bookingRules: RenderableItineraryOfferBookingRules;
}

declare enum EitherResponseType {
    SUCCESS = "SUCCESS",
    ERROR = "ERROR"
}
type SuccessResponse<T> = {
    type: EitherResponseType.SUCCESS;
    success: T;
};
type ErrorResponse<E> = {
    type: EitherResponseType.ERROR;
    error: E;
};
type EitherResponse<T, E> = SuccessResponse<T> | ErrorResponse<E>;
declare const successResponse: <T>(data: T) => SuccessResponse<T>;
declare const errorResponse: <E>(error: E) => ErrorResponse<E>;

interface BundleBifrostFormQuestionWithResponseProps {
    bifrostFormQuestion: BifrostFormQuestion;
}
declare const bundleBifrostFormQuestionWithResponse: ({ bifrostFormQuestion, }: BundleBifrostFormQuestionWithResponseProps) => {
    bifrostFormQuestionWithResponse: BifrostFormQuestionWithResponse;
};

interface UpdateBifrostFormQuestionWithResponseProps {
    previousBifrostFormQuestionWithResponse: BifrostFormQuestionWithResponse;
    updatedBifrostFormQuestionResponse: BifrostFormQuestionResponse;
}
declare const updateBifrostFormQuestionWithResponse: ({ previousBifrostFormQuestionWithResponse, updatedBifrostFormQuestionResponse, }: UpdateBifrostFormQuestionWithResponseProps) => BifrostFormQuestionWithResponse;

interface UseReactStateCacheProps<T> {
    previousValue: T;
    updatedValue: T;
}
declare const useReactStateCache: <T extends object>({ previousValue, updatedValue, }: UseReactStateCacheProps<T>) => T;

declare const deepClone: <T>(obj: T) => T;

declare const deepEqual: <T extends object>(object1?: T, object2?: T) => boolean;

declare enum RenderedCalendarDateFormat {
    MM_SLASH_DD_SLASH_YY = "MM_SLASH_DD_SLASH_YY",
    ABBREVIATED_MONTH_DAY_OPTIONAL_YEAR = "ABBREVIATED_MONTH_DAY_OPTIONAL_YEAR",
    MONTH_DAY_YEAR = "MONTH_DAY_YEAR",
    MONTH = "MONTH"
}

interface RenderCalendarDateProps {
    calendarDate: CalendarDate;
    format: RenderedCalendarDateFormat;
}
declare const renderCalendarDate: ({ calendarDate, format, }: RenderCalendarDateProps) => string;

declare enum RenderedCalendarDateRangeJoinFormat {
    SPACE_DASH_SPACE = "SPACE_DASH_SPACE"
}

interface RenderedCalendarDateCollapseStrategy {
    collapseSameDay: boolean;
    collapseSameMonth: boolean;
}
interface RenderCalendarDateRangeProps {
    calendarDateRange: CalendarDateRange;
    renderedCalendarDateFormat: RenderedCalendarDateFormat;
    renderedCalendarDateRangeJoinFormat: RenderedCalendarDateRangeJoinFormat;
    collapseStrategy: RenderedCalendarDateCollapseStrategy;
}
declare const renderCalendarDateRange: ({ calendarDateRange, renderedCalendarDateFormat, renderedCalendarDateRangeJoinFormat, collapseStrategy, }: RenderCalendarDateRangeProps) => string;

declare enum CalendarDateComarison {
    FIRST_DATE_OCCURS_BEFORE_SECOND_DATE = -1,
    FIRST_DATE_OCCURS_AFTER_SECOND_DATE = 1,
    DATES_ARE_EQUAL = 0
}
interface CompareCalendarDatesProps {
    firstCalendarDate: CalendarDate;
    secondCalendarDate: CalendarDate;
}
declare function compareCalendarDates({ firstCalendarDate, secondCalendarDate, }: CompareCalendarDatesProps): CalendarDateComarison;

interface ConvertCalendarDateToDateAdjustedForTimezoneProps {
    calendarDate: CalendarDate;
}
declare const convertCalendarDateToDateAdjustedForTimezone: ({ calendarDate, }: ConvertCalendarDateToDateAdjustedForTimezoneProps) => Date;

declare const convertLocalCalendarDateToNativeDate: (calendarDate: CalendarDate) => Date;

declare const convertNativeDateToLocalCalendarDate: (date: Date) => CalendarDate;

interface GetDaysBetweenCalendarDatesProps {
    startCalendarDate: CalendarDate;
    endCalendarDate: CalendarDate;
}
declare const getDaysBetweenCalendarDates: ({ startCalendarDate, endCalendarDate, }: GetDaysBetweenCalendarDatesProps) => {
    days: number;
};

interface GetTodayCalendarDateProps {
    timeZone?: string;
}
declare const getTodayCalendarDate: ({ timeZone, }: GetTodayCalendarDateProps) => CalendarDate;

interface GetRoomCountFromRenderableItineraryOfferProps {
    renderableItineraryOffer: RenderableItineraryOffer;
}
declare const getRoomCountFromRenderableItineraryOffer: ({ renderableItineraryOffer, }: GetRoomCountFromRenderableItineraryOfferProps) => number;

interface GetTotalListPriceInCentsFromRenderableItineraryOfferProps {
    renderableItineraryOffer: RenderableItineraryOffer;
}
declare const getTotalListPriceInCentsFromRenderableItineraryOffer: ({ renderableItineraryOffer, }: GetTotalListPriceInCentsFromRenderableItineraryOfferProps) => {
    totalListPriceInCents: number;
};

interface GetTotalOfferPriceInCentsFromRenderableItineraryOfferProps {
    renderableItineraryOffer: RenderableItineraryOffer;
}
declare const getTotalOfferPriceInCentsFromRenderableItineraryOffer: ({ renderableItineraryOffer, }: GetTotalOfferPriceInCentsFromRenderableItineraryOfferProps) => {
    totalOfferPriceInCents: number;
};

interface RenderDiscountProps {
    listPriceInCents: number;
    offerPriceInCents: number;
}
declare const renderDiscount: ({ listPriceInCents, offerPriceInCents, }: RenderDiscountProps) => string;

interface FormatPhoneNumberProps {
    phoneNumber: string;
}
declare const formatPhoneNumber: ({ phoneNumber }: FormatPhoneNumberProps) => string;

declare const getDiscountPercent: ({ listPrice, offerPrice, decimalPlaces, }: {
    listPrice: number;
    offerPrice: number;
    decimalPlaces: number;
}) => string;

export { type BaseBifrostFormQuestionResponse, type BaseBifrostFormQuestionWithResponse, type BaseRenderableBifrostFormQuestion, type BifrostFormQuestion, type BifrostFormQuestionCalendarDateRangeResponse, type BifrostFormQuestionEmailResponse, type BifrostFormQuestionMultiCalendarDateRangeResponse, type BifrostFormQuestionPhoneNumberResponse, type BifrostFormQuestionResponse, BifrostFormQuestionResponseType, type BifrostFormQuestionSplitTextResponse, type BifrostFormQuestionTextResponse, BifrostFormQuestionType, type BifrostFormQuestionWithCalendarDateRangeResponse, type BifrostFormQuestionWithEmailResponse, type BifrostFormQuestionWithMultiCalendarDateRangeResponse, type BifrostFormQuestionWithPhoneNumberResponse, type BifrostFormQuestionWithResponse, type BifrostFormQuestionWithSplitTextResponse, type BifrostFormQuestionWithTextResponse, type BifrostTextAreaFormQuestionWithTextResponse, type BifrostTextInputFormQuestionWithTextResponse, type BifrostToggleButtonGroupFormQuestionWithTextResponse, type CalendarDate, CalendarDateComarison, type CalendarDateRange, type CompareCalendarDatesProps, type EitherResponse, EitherResponseType, type ErrorResponse, ItineraryOfferOriginatorType, type PendingCalendarDateRange, type RenderableEmailInputBifrostFormQuestion, type RenderableItineraryEventOffer, RenderableItineraryEventOfferApprovalStatus, type RenderableItineraryHotelRoomOffer, type RenderableItineraryOffer, type RenderableItineraryOfferBookingRules, type RenderableItineraryOfferCriterion, type RenderableMultiSelectDateRangeBifrostFormQuestion, type RenderablePhoneInputBifrostFormQuestion, type RenderableSelectDateRangeBifrostFormQuestion, type RenderableSplitTextInputBifrostFormQuestion, type RenderableTextAreaBifrostFormQuestion, type RenderableTextInputBifrostFormQuestion, type RenderableToggleButtonGroupBifrostFormQuestion, type RenderableToggleButtonGroupBifrostFormQuestionOption, type RenderedCalendarDateCollapseStrategy, RenderedCalendarDateFormat, RenderedCalendarDateRangeJoinFormat, ReservedBifrostDateFlexibilityOptionValues, ReservedBifrostFormQuestionIds, ReservedBifrostReasonForTravelOptionValues, ReservedBifrostSplitPaymentOptionValues, type SingleRenderableBifrostFormQuestion, type SuccessResponse, type UseReactStateCacheProps, bundleBifrostFormQuestionWithResponse, compareCalendarDates, convertCalendarDateToDateAdjustedForTimezone, convertLocalCalendarDateToNativeDate, convertNativeDateToLocalCalendarDate, deepClone, deepEqual, errorResponse, formatPhoneNumber, getDaysBetweenCalendarDates, getDiscountPercent, getRoomCountFromRenderableItineraryOffer, getTodayCalendarDate, getTotalListPriceInCentsFromRenderableItineraryOffer, getTotalOfferPriceInCentsFromRenderableItineraryOffer, renderCalendarDate, renderCalendarDateRange, renderDiscount, successResponse, updateBifrostFormQuestionWithResponse, useReactStateCache };
